ssh

package
v1.28.0-dev Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 29, 2026 License: MIT Imports: 24 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GenKeyPair added in v1.8.0

func GenKeyPair(keyPath string, keyType generate.SSHKeyType, bits int) error

GenKeyPair make a pair of public and private keys for SSH access. Public key is encoded in the format for inclusion in an OpenSSH authorized_keys file. Private Key generated is PEM encoded

func Init added in v1.27.0

func Init() error

func InitDefaultHostKeys added in v1.27.0

func InitDefaultHostKeys(path string) (keyFiles []string, _ error)

InitDefaultHostKeys mirrors how ssh-keygen -A operates it runs checks if public and private keys are already defined and creates new ones if not present key naming does not follow the OpenSSH convention due to existing settings being gitea.{KeyType} so generation follows gitea convention

func Listen

func Listen(host string, port int, ciphers, keyExchanges, macs []string)

Listen starts an SSH server listening on given port.

Types

This section is empty.

Jump to