Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenKeyPair ¶ added in v1.8.0
func GenKeyPair(keyPath string, keyType generate.SSHKeyType, bits int) error
GenKeyPair make a pair of public and private keys for SSH access. Public key is encoded in the format for inclusion in an OpenSSH authorized_keys file. Private Key generated is PEM encoded
func InitDefaultHostKeys ¶ added in v1.27.0
InitDefaultHostKeys mirrors how ssh-keygen -A operates it runs checks if public and private keys are already defined and creates new ones if not present key naming does not follow the OpenSSH convention due to existing settings being gitea.{KeyType} so generation follows gitea convention
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.